package com.zehong.dangerousdevicereport.service.impl;

import cn.hutool.core.date.DateUtil;
import com.zehong.dangerousdevicereport.dao.TAlarmInfoDao;
import com.zehong.dangerousdevicereport.entity.TAlarmInfo;
import com.zehong.dangerousdevicereport.service.ITAlarmInfoService;
import org.springframework.stereotype.Service;
import javax.annotation.Resource;
import java.util.List;

/**
 * 【报警】Service业务层处理
 * 
 * @author zehong
 * @date 2022-04-12
 */
@Service
public class TAlarmInfoServiceImpl implements ITAlarmInfoService {

    @Resource
    private TAlarmInfoDao tAlarmInfoDao;

    /**
     * 查询【报警】
     * 
     * @param id 【报警】ID
     * @return 【报警】
     */
    @Override
    public TAlarmInfo selectTAlarmInfoById(String id){
        return tAlarmInfoDao.selectTAlarmInfoById(id);
    }

    /**
     * 查询【报警】列表
     * 
     * @param tAlarmInfo 【报警】
     * @return 【报警】
     */
    @Override
    public List<TAlarmInfo> selectTAlarmInfoList(TAlarmInfo tAlarmInfo){
        return tAlarmInfoDao.selectTAlarmInfoList(tAlarmInfo);
    }

    /**
     * 新增【报警】
     * 
     * @param tAlarmInfo 【报警】
     * @return 结果
     */
    @Override
    public int insertTAlarmInfo(TAlarmInfo tAlarmInfo){
        tAlarmInfo.setCreateTime(DateUtil.date());
        return tAlarmInfoDao.insertTAlarmInfo(tAlarmInfo);
    }

    /**
     * 修改【报警】
     * 
     * @param tAlarmInfo 【报警】
     * @return 结果
     */
    @Override
    public int updateTAlarmInfo(TAlarmInfo tAlarmInfo){
        return tAlarmInfoDao.updateTAlarmInfo(tAlarmInfo);
    }

    /**
     * 批量删除【报警】
     * 
     * @param ids 需要删除的【报警】ID
     * @return 结果
     */
    @Override
    public int deleteTAlarmInfoByIds(String[] ids){
        return tAlarmInfoDao.deleteTAlarmInfoByIds(ids);
    }

    /**
     * 删除【报警】信息
     * 
     * @param id 【报警】ID
     * @return 结果
     */
    @Override
    public int deleteTAlarmInfoById(String id){
        return tAlarmInfoDao.deleteTAlarmInfoById(id);
    }

    /**
     * 根据设备编号查询报警信息
     * @param deviceNum 设备编号
     * @return
     */
    @Override
    public TAlarmInfo selectAlarmInfoByDeviceNum(String deviceNum){
        return tAlarmInfoDao.selectAlarmInfoByDeviceNum(deviceNum);
    }
}
